==> ocstore25_4_23.zip: OcStore/Prgm/data/map/CS_soapcastle_golemstatue.lua <==
function E0090()
    MNA()CMU("XXXX")FAI(0)
end
function E0091()
    MNA()CMU("XXXX")FAI(1)
end
function E0092()
    MNA()CMU("XXXX")FAI(2)
end
function E0093()
    MNA()CMU("XXXX")FAI(3)
end
function E0094()
    MNA()CMU("XXXX")FAI(4)
end

function GoSoapCastleStair()
    PRI()FAO(1)TRA("CS_soapcastle_stair","E0093",2,20,0,76)
end

function CheckStatue()
    PRI()
    FAC("jack_normal")MS4("\n这些雕像看起来有点令人不安...")NOD()
end

function GolemWake()
    KEY()
    FON("GolemWake")
    MM0()WAS()
    WAI(32)
    FAC("tap_normal")MS3("那两个家伙也太不靠谱了，")NOD()
    CAT("\n结果事情还是得我来收尾...")NOD()CLO()
    WAI(32)
    ANP("Status","wake")
    WAI(32)
    PRI()
    FAC("jack_normal")MS3("\n遭了！是陷阱！")NOD()CLR()
    FAC("tap_normal")CAT("\n弟兄们！快抓住它们！")NOD()CLR()
    FAC("jack_><")CAT("倒霉啊！")NOD()
    CAT("\n我和桑塔果然还是难逃一劫嘛...")NOD()CLO()
    FAO(0)
    FOM()
    DNP("GolemWake")
    --各种声音
    SOU("CS_052_enemy_hurt_big")
    WAI(16)
    SOU("CS_105_puppy_bark")
    WAI(16)
    SOU("CS_052_enemy_hurt_big")
    WAI(16)
    SOU("CS_052_enemy_hurt_big")
    WAI(8)
    SOU("CS_052_enemy_hurt_big")
    WAI(8)
    SOU("CS_052_enemy_hurt_big")
    WAI(16)
    SOU("CS_050_mimiga_squeak")
    WAI(16)
    SOU("CS_050_mimiga_squeak")
    WAI(16)
    SOU("CS_052_enemy_hurt_big")
    WAI(8)
    SOU("CS_052_enemy_hurt_big")
    WAI(8)
    SOU("CS_050_mimiga_squeak")
    WAI(16)
    SOU("CS_071_little_crash")
    WAI(60)
    SOU("CS_071_little_crash")
    WAI(60)
    SOU("CS_puppy_hurt")
    FLS("GolemTrap")
    TRA("CS_soapcastle_jail","CatchedJackSanta",3,12)
end

==> ocstore25_12_22.zip: OcStore/Prgm/data/map/CS_soapcastle_golemstatue.lua <==
function E0090()
    MNA()CMU("XXXX")FAI(0)
end
function E0091()
    MNA()CMU("XXXX")FAI(1)
end
function E0092()
    MNA()CMU("XXXX")FAI(2)
end
function E0093()
    MNA()CMU("XXXX")FAI(3)
end
function E0094()
    MNA()CMU("XXXX")FAI(4)
end

function GoSoapCastleGolemHall()
    PRI()FAO(3)TRA("CS_soapcastle_golemhall","E0091",75,18,0,2)
end

function GoSoapCastleStair()
    PRI()FAO(1)TRA("CS_soapcastle_stair","E0093",2,20,0,76)
end

function Statue()
    PRI()
    FAC("jack_normal")MS4("\n这些雕像看起来有点令人不安...")NOD()
end

function GolemWake()
    KEY()
    FON("GolemWake")
    MM0()WAS()
    WAI(32)
    FAC("tap_normal")MS3("那两个家伙也太不靠谱了，")NOD()
    CAT("\n结果事情还是得我来收尾...")NOD()CLO()
    WAI(32)
    ANP("Statue","wake")
    WAI(32)
    PRI()
    FAC("jack_normal")MS3("\n遭了！是陷阱！")NOD()CLR()
    FAC("tap_normal")CAT("\n弟兄们！快抓住它们！")NOD()CLR()
    FAC("jack_><")CAT("倒霉啊！")NOD()
    CAT("\n我和桑塔果然还是难逃一劫嘛...")NOD()CLO()
    FAO(0)
    FOM()
    DNP("GolemWake")
    --各种声音
    SOU("CS_052_enemy_hurt_big")
    WAI(16)
    SOU("CS_105_puppy_bark")
    WAI(16)
    SOU("CS_052_enemy_hurt_big")
    WAI(16)
    SOU("CS_052_enemy_hurt_big")
    WAI(8)
    SOU("CS_052_enemy_hurt_big")
    WAI(8)
    SOU("CS_052_enemy_hurt_big")
    WAI(16)
    SOU("CS_050_mimiga_squeak")
    WAI(16)
    SOU("CS_050_mimiga_squeak")
    WAI(16)
    SOU("CS_052_enemy_hurt_big")
    WAI(8)
    SOU("CS_052_enemy_hurt_big")
    WAI(8)
    SOU("CS_050_mimiga_squeak")
    WAI(16)
    SOU("CS_071_little_crash")
    WAI(60)
    SOU("CS_071_little_crash")
    WAI(60)
    SOU("CS_puppy_hurt")
    FLS("GolemTrap")
    TRA("CS_soapcastle_jail","CatchedJackSanta",3,12)
end

function PuppyAppear()
    KEY()
    FON("PuppyAppear",16)
    MM0()
    SLR(1)
    WAS()
    WAI(32)
    --小狗出现了
    SNP("CS_puppy_animate",76,17,0,"mainLayer","Puppy1")
    WAI(60)
    FAC("curly_happy")MS3("\n是珍卡的小狗诶！")NOD()CLO()
    ANP("Puppy1","bark",0)
    WAI(32)
    ANP("Puppy1","walk",0)
    WAI(64)
    ANP("Puppy1","sleep",0)
    WAI(128)
    FAC("curly_normal")MS3("\n！！！")NOD()CLR()
    FAC("curly_sad")CAT("它看起来受了点轻伤")
    CAT("\n也筋疲力尽了...")NOD()CLR()
    FAC("curly_normal")CAT("虽然我们很想立马去救大家，")NOD()
    CAT("\n但也不能丢下它不管...")NOD()CLR()
    CAT("我们先找一个安全的地方把它藏起来")
    CAT("\n再和数码它们商量一下吧。")NOD()CLO()
    FAO(1)
    FOM()
    FLS("PuppyAppear")
    DNP("PuppyAppear")
    TRA("CS_soapcastle_kingbedroom","HidePuppy",9,15)
end
